==> trilinos_9.0.3.dfsg.orig.tar.gz: trilinos-9.0.3.dfsg.orig/packages/phdmesh/src/element/ElementDimensions.cpp <==
/*------------------------------------------------------------------------*/
/*      phdMesh : Parallel Heterogneous Dynamic unstructured Mesh         */
/*                Copyright (2007) Sandia Corporation                     */
/*                                                                        */
/*  Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive   */
/*  license for use of this work by or on behalf of the U.S. Government.  */
/*                                                                        */
/*  This library is free software; you can redistribute it and/or modify  */
/*  it under the terms of the GNU Lesser General Public License as        */
/*  published by the Free Software Foundation; either version 2.1 of the  */
/*  License, or (at your option) any later version.                       */
/*                                                                        */
/*  This library is distributed in the hope that it will be useful,       */
/*  but WITHOUT ANY WARRANTY; without even the implied warranty of        */
/*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     */
/*  Lesser General Public License for more details.                       */
/*                                                                        */
/*  You should have received a copy of the GNU Lesser General Public      */
/*  License along with this library; if not, write to the Free Software   */
/*  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307   */
/*  USA                                                                   */
/*------------------------------------------------------------------------*/
/**
 * @author H. Carter Edwards
 */

#include <element/Dimensions.hpp>

namespace phdmesh {

const char * ElementNode::name() const
{ static const char n[] = "ElementNode" ; return n ; }

const ElementNode & ElementNode::descriptor()
{ static const ElementNode self ; return self ; }

const char * QuadratureTag::name() const
{ static const char n[] = "Quadrature" ; return n ; }

const QuadratureTag & QuadratureTag::descriptor()
{ static const QuadratureTag self ; return self ; }

const char * BasisTag::name() const
{ static const char n[] = "Basis" ; return n ; }

const BasisTag & BasisTag::descriptor()
{ static const BasisTag self ; return self ; }

} // namespace phdmesh

==> trilinos_10.0.4.dfsg.orig.tar.gz: trilinos-10.0.4.dfsg.orig/packages/phdmesh/src/element/ElementDimensions.cpp <==
/*------------------------------------------------------------------------*/
/*      phdMesh : Parallel Heterogneous Dynamic unstructured Mesh         */
/*                Copyright (2007) Sandia Corporation                     */
/*                                                                        */
/*  Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive   */
/*  license for use of this work by or on behalf of the U.S. Government.  */
/*                                                                        */
/*  This library is free software; you can redistribute it and/or modify  */
/*  it under the terms of the GNU Lesser General Public License as        */
/*  published by the Free Software Foundation; either version 2.1 of the  */
/*  License, or (at your option) any later version.                       */
/*                                                                        */
/*  This library is distributed in the hope that it will be useful,       */
/*  but WITHOUT ANY WARRANTY; without even the implied warranty of        */
/*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     */
/*  Lesser General Public License for more details.                       */
/*                                                                        */
/*  You should have received a copy of the GNU Lesser General Public      */
/*  License along with this library; if not, write to the Free Software   */
/*  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307   */
/*  USA                                                                   */
/*------------------------------------------------------------------------*/
/**
 * @author H. Carter Edwards
 */

#include <element/Dimensions.hpp>

namespace phdmesh {

const char * ElementNode::name() const
{ static const char n[] = "ElementNode" ; return n ; }

const ElementNode & ElementNode::tag()
{ static const ElementNode self ; return self ; }

const char * QuadratureTag::name() const
{ static const char n[] = "Quadrature" ; return n ; }

const QuadratureTag & QuadratureTag::tag()
{ static const QuadratureTag self ; return self ; }

const char * BasisTag::name() const
{ static const char n[] = "Basis" ; return n ; }

const BasisTag & BasisTag::tag()
{ static const BasisTag self ; return self ; }

} // namespace phdmesh
